/* Monaco GP video hardware simulation */

#include "monaco.h"

#define plot_pixel(bitmap,x,y,col)	do { bitmap.pix16(y, x) = col; } while (0)

void monaco_state::draw_computer( bitmap_ind16 &bitmap, const rectangle clip )
{
	int i;

	for( i=0; i<NUM_COMPUTER_CARS; i++ )
	{
		drawgfx_transpen(
			bitmap, clip, machine().gfx[GFX_COMPUTER],
			m_tile[i],
			m_color[i],
			0,0,
			m_x[i],
			m_y[i],
			0 );
	}

	drawgfx_transpen(
		bitmap, clip, machine().gfx[GFX_RESCUE_CAR],
		m_rescue_tile,
		0, /* color */
		0,0,
		m_rescue_x,
		m_rescue_y,
		0 );
}

void monaco_state::draw_pool( bitmap_ind16 &bitmap, const rectangle clip )
{
	drawgfx_transpen(
		bitmap, clip, machine().gfx[GFX_POOL],
		0,0, /* tile,color */
		0,0, /* flip */
		m_pool_x,
		m_pool_y,
		0 );
}

void monaco_state::draw_player( bitmap_ind16 &bitmap, const rectangle clip )
{
	int gfx;
	int tile;

	switch( m_player_splash )
	{
	case 0:
		drawgfx_transpen( bitmap, clip, machine().gfx[GFX_SPRAY],
			2,0,0,0,
			m_player_x,
			m_player_y+32-8,
			0);
		drawgfx_transpen( bitmap, clip, machine().gfx[GFX_SPRAY],
			0,0,0,0,
			m_player_x,
			m_player_y-32+8,
			0);
		break;
	case 1:
		drawgfx_transpen( bitmap, clip, machine().gfx[GFX_SPRAY],
			3,0,0,0,
			m_player_x,
			m_player_y+32-8,
			0);
		drawgfx_transpen( bitmap, clip, machine().gfx[GFX_SPRAY],
			1,0,0,0,
			m_player_x,
			m_player_y-32+8,
			0);
		break;
	}

	tile = m_player_tile;
	gfx = 0;
	if( tile>=0 )
	{
		switch( tile )
		{
		case 0:
		case 1: gfx = GFX_PLAYER; break;

		case 2:
		case 3: gfx = GFX_SPINOUT1; tile -= 2; break;

		case 4:
		case 5: gfx = GFX_SPINOUT2; tile -= 4; break;

		case 6:
		case 7:
		case 8:
		case 9: gfx = GFX_EXPLOSION; tile -= 6; break;

		case 10:
		case 11: gfx = GFX_SHAKE; tile -= 10; break;
		}

		drawgfx_transpen( bitmap, clip, machine().gfx[gfx],
			tile,0,
			0,0,
			m_player_x,
			m_player_y,
			0);
	}
}

/*****************************************************************/

void monaco_state::draw_strip( bitmap_ind16 &bitmap, int sy, int x0, int x1, int xpos, int pen )
{
	int sx;
	if( x0<xpos ) x0 = xpos;
	if( x1>xpos+PAGE_SIZE ) x1 = xpos+PAGE_SIZE;
	if( x0<0 ) x0 = 0;
	if( x1>SCREEN_WIDTH ) x1 = SCREEN_WIDTH;
	for( sx=x0; sx<x1; sx++ ) plot_pixel( bitmap,sx,sy,pen );
}

void monaco_state::DrawSmoothZone( bitmap_ind16 &bitmap, const rectangle clip, int xpos )
{
	const UINT8 data[14] =
	{
		GFX_GRASS,GFX_GRASS,GFX_GRASS,
		GFX_TREE,GFX_GRASS,GFX_TREE,
		GFX_GRASS,GFX_HOUSE,GFX_GRASS,
		GFX_SHRUB,GFX_SHRUB,
		GFX_GRASS,GFX_GRASS,GFX_GRASS
	};
	int top_inset = m_top_inset;
	int bottom_inset = m_bottom_inset;
	int i;

	draw_strip( bitmap, top_inset, xpos, xpos+PAGE_SIZE, xpos, YELLOW_PEN );
	draw_strip( bitmap, SCREEN_HEIGHT-1 - bottom_inset, xpos, xpos+PAGE_SIZE, xpos, YELLOW_PEN );

	for( i=0; i<14; i++ )
	{
		int code = data[i];
		gfx_element *gfx = machine().gfx[code];
		gfx_element *belt = machine().gfx[(code==GFX_HOUSE)?GFX_DUMMY:GFX_BELT];
		int j;

		for( j=0; j<3; j++ )
		{
			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos, m_top_inset-32-16-j*32 );

			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos,SCREEN_HEIGHT-m_bottom_inset+j*32+16-8 );
		}
		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos, m_top_inset-16 );

		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos,SCREEN_HEIGHT-m_bottom_inset );

		xpos += 32;
	}
}

void monaco_state::DrawSlipZone( bitmap_ind16 &bitmap, const rectangle clip, int xpos )
{
	const UINT8 data[14] =
	{
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,GFX_HOUSE,
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,/* start  */GFX_SHRUB,GFX_SHRUB
	};

	int top_inset = m_top_inset;
	int bottom_inset = m_bottom_inset;
	int i;

	draw_strip( bitmap, top_inset, xpos, xpos+PAGE_SIZE, xpos, YELLOW_PEN );
	draw_strip( bitmap, SCREEN_HEIGHT-1 - bottom_inset, xpos, xpos+PAGE_SIZE, xpos, YELLOW_PEN );

	for( i=0; i<14; i++ ){
		int code = data[i];
		gfx_element *gfx = machine().gfx[code];
		gfx_element *belt = machine().gfx[(code==GFX_HOUSE)?GFX_DUMMY:GFX_BELT];
		int j;

		for( j=0; j<3; j++ ){
			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos, top_inset-32-j*32-16 );

			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos,SCREEN_HEIGHT-bottom_inset+j*32+16-8 );
		}

		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos, top_inset-16 );

		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos,SCREEN_HEIGHT-bottom_inset );

		xpos += 32;
	}
}

void monaco_state::DrawGravelZone( bitmap_ind16 &bitmap, const rectangle clip, int xpos )
{
	const UINT8 data[14] = {
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,GFX_HOUSE,
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB,
		GFX_SHRUB,GFX_SHRUB,GFX_SHRUB
	};
	int top_inset = m_top_inset;
	int bottom_inset = m_bottom_inset;
	int i;
	int xpos0 = xpos;

	for( i=0; i<14; i++ )
	{
		int code = data[i];
		gfx_element *gfx = machine().gfx[code];
		gfx_element *belt = machine().gfx[(code==GFX_HOUSE)?GFX_DUMMY:GFX_BELT];
		int j;
		int ypos;

		/* draw gravel */
		if( data[i]!=GFX_HOUSE )
		{
			ypos = SCREEN_HEIGHT-bottom_inset-32;
			drawgfx_opaque( bitmap, clip, machine().gfx[GFX_BELT],
				1,1, /* number, color */
				0,0, /* no flip */
				xpos, ypos+32-8 );
			ypos-=24;
			while( ypos>0 ){
				drawgfx_opaque( bitmap, clip, machine().gfx[GFX_BELT],
					1,1, /* number, color */
					0,0, /* no flip */
					xpos, ypos );
				ypos -= 16;
			}
		}

		for( j=0; j<3; j++ )
		{
			ypos = SCREEN_HEIGHT-bottom_inset+16+j*32-8;
			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos, ypos );
		}

		for( j=0; j<3; j++ )
		{
			ypos = top_inset-32-16-j*32;
			drawgfx_opaque( bitmap, clip, gfx,
				0,0, /* number, color */
				0,0, /* no flip */
				xpos, ypos );
		}

		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos, top_inset-16 );

		drawgfx_opaque( bitmap, clip, belt,
			0,0, /* number, color */
			0,0, /* no flip */
			xpos,SCREEN_HEIGHT-bottom_inset );


		xpos += 32;
	}
	draw_strip( bitmap, top_inset, xpos0, xpos0+PAGE_SIZE, xpos0, YELLOW_PEN );
	draw_strip( bitmap, SCREEN_HEIGHT-1 - bottom_inset, xpos0, xpos0+PAGE_SIZE, xpos0, YELLOW_PEN );
}

void monaco_state::DrawBridgeZone( bitmap_ind16 &bitmap, const rectangle clip, int xpos )
{
	gfx_element *gfx1 = machine().gfx[GFX_BRIDGE1];
	gfx_element *gfx2 = machine().gfx[GFX_BRIDGE2];

	int i;
	for( i=0; i<14; i++ )
	{
		int j;
		gfx_element *gfx = (i==0)?gfx2:gfx1;
		for( j=0; j<7; j++ )
		{
			int flip;
			for( flip=0; flip<=1; flip++ )
			{
				int ypos = flip?(SCREEN_HEIGHT-16-j*16)+8:j*16-8;
				if( j<5 )
				{ /* water */
					drawgfx_opaque( bitmap, clip, gfx1,
						0,0, /* number, color */
						0,flip,
						xpos, ypos );
				}
				else
				{ /* edge of bridge */
					drawgfx_opaque( bitmap, clip, gfx,
						j-5,0, /* number, color */
						0,flip,
						xpos, ypos );
				}
			}
		}
		xpos += 32;
	}
}

void monaco_state::DrawTunnelZone( bitmap_ind16 &bitmap, int xpos )
{
	int pen = YELLOW_PEN;
	int top_inset = m_top_inset;
	int bottom_inset = m_bottom_inset;
	draw_strip( bitmap, top_inset, xpos, xpos+PAGE_SIZE, xpos, pen );
	draw_strip( bitmap, SCREEN_HEIGHT-1 - bottom_inset, xpos, xpos+PAGE_SIZE, xpos, pen );
}

void monaco_state::DrawTunnelWall( bitmap_ind16 &bitmap, const rectangle clip, int xpos )
{
	rectangle clip2;
	gfx_element *gfx = machine().gfx[GFX_TUNNEL];
	int top_inset = m_top_inset - 16;
	int bottom_inset = m_bottom_inset - 16;
	int i;

	clip2.min_x = clip.min_x;
	clip2.max_x = clip.max_x;
	clip2.max_y = clip.max_y;
	clip2.min_y = SCREEN_HEIGHT-bottom_inset;

	for( i=0; i<14; i++ )
	{
		int j;
		for( j=0; j<2; j++ )
		{
			drawgfx_transpen( bitmap, clip, gfx,
				1,0, /* number, color */
				0,0, /* no flip */
				xpos, top_inset-32-j*32, 0 );

			drawgfx_transpen( bitmap, clip, gfx,
				1,0, /* number, color */
				0,0, /* no flip */
				xpos, SCREEN_HEIGHT-bottom_inset+j*32 - 8, 0 );
		}
		xpos += 32;
	}
}

void monaco_state::draw_light_helper( bitmap_ind16 &bitmap, int xpos )
{
	int pen = BLACK_PEN;
	const unsigned char *source = memregion( "gfx1" )->base();
	int x0 = m_player_x-128;
	int y0 = m_player_y-48;
	int sy;
	for( sy=0; sy<SCREEN_HEIGHT; sy++ )
	{
		int i = sy-y0;
		if( i<0 || i>=128 )
		{
			draw_strip( bitmap, sy, xpos, xpos+PAGE_SIZE, xpos, pen );
		}
		else
		{
			int left = x0+source[i];
			int right = x0+source[i+128];
			draw_strip( bitmap, sy, xpos, left, xpos, pen );
			draw_strip( bitmap, sy, right, xpos+PAGE_SIZE, xpos, pen );
		}
	}
}

void monaco_state::draw_wall( bitmap_ind16 &bitmap, const rectangle clip )
{
	if( m_right_page == PAGE_TUNNEL )
		DrawTunnelWall( bitmap, clip, SCREEN_WIDTH-14*32+m_scroll );

	if( m_left_page == PAGE_TUNNEL )
		DrawTunnelWall( bitmap, clip, SCREEN_WIDTH-14*32*2+m_scroll );
}

void monaco_state::draw_light( bitmap_ind16 &bitmap )
{
	if( m_right_page == PAGE_TUNNEL )
		draw_light_helper( bitmap, SCREEN_WIDTH-14*32+m_scroll );

	if( m_left_page == PAGE_TUNNEL )
		draw_light_helper( bitmap, SCREEN_WIDTH-14*32*2+m_scroll );
}

void monaco_state::draw_page( bitmap_ind16 &bitmap, const rectangle clip, int which, int xpos )
{
	rectangle r;
	r.min_x = xpos;
	r.max_x = xpos+PAGE_SIZE-1;
	r.min_y = 0;
	r.max_y = SCREEN_HEIGHT-1;
	bitmap.fill( (which!=PAGE_SLIP)?GREY_PEN:CYAN_PEN,r );
	switch( which )
	{
	case PAGE_SMOOTH:
		DrawSmoothZone( bitmap, clip, xpos );
		break;

	case PAGE_SLIP:
		DrawSlipZone( bitmap, clip, xpos );
		break;

	case PAGE_TUNNEL:
		DrawTunnelZone( bitmap, xpos );
		break;

	case PAGE_GRAVEL:
		DrawGravelZone( bitmap, clip, xpos );
		break;

	case PAGE_BRIDGE:
		DrawBridgeZone( bitmap, clip, xpos );
		break;
	}
}

void monaco_state::draw_background( bitmap_ind16 &bitmap, const rectangle clip )
{
	draw_page(bitmap, clip,
		m_right_page,
		SCREEN_WIDTH-14*32+m_scroll );

	draw_page(bitmap, clip,
		m_left_page,
		SCREEN_WIDTH-14*32*2+m_scroll );
}

void monaco_state::draw_text( bitmap_ind16 &bitmap, const rectangle clip )
{
	int sx = (SCREEN_WIDTH-8)/2;
	int sy = (SCREEN_HEIGHT-128)/2;

	if( m_left_text != -1 )
	{
		drawgfxzoom_transpen( bitmap, clip, machine().gfx[GFX_TEXT],
			m_left_text,0,
			0,0, /* flip */
			sx-96,sy,
			1<<16, 2<<16, 0
		);
	}

	if( m_right_text != -1 )
	{
		drawgfxzoom_transpen( bitmap, clip, machine().gfx[GFX_TEXT],
			m_right_text,1,
			0,0, /* flip */
			SCREEN_WIDTH-32,sy,
			1<<16, 2<<16, 0
		);
	}
}

/* last two values are L and H used to display in gear field (not supported officially)*/
static const UINT8 led_map[12] = { 0x3f,0x06,0x5b,0x4f,0x66,0x6d,0x7d,0x07,0x7f,0x6f,0x38,0x76 };

/* following outputs LED's for bezel. also displays time,score&speed text versions (text version disabled here) */

void monaco_state::draw_leds( bitmap_ind16 &bitmap )
{
	int i;
	UINT32 data;

//	data = m_speed;
//	for( i=2; i>=0; i-- )
//	{
//		drawgfx_transpen( bitmap, led_font,
//			data%10,0, /* number, color */
//			0,1, /* no flip */
//			9,SCREEN_HEIGHT-6-i*6,
//			NULL, TRANSPARENCY_NONE,0 );
//
//		data = data/10;
//	}

	data = m_led_high1>>8;
	for( i=3; i>=0; i-- )
	{
		output_set_digit_value(i+10, led_map[data%10]);
		data = data/10;
	}

	data = m_led_high2>>8;
	for( i=3; i>=0; i-- )
	{
		output_set_digit_value(i+20, led_map[data%10]);
		data = data/10;
	}

	data = m_led_high3>>8;
	for( i=3; i>=0; i-- )
	{
		output_set_digit_value(i+30, led_map[data%10]);
		data = data/10;
	}

	data = m_led_high4>>8;
	for( i=3; i>=0; i-- )
	{
		output_set_digit_value(i+40, led_map[data%10]);
		data = data/10;
	}

	data = m_led_high5>>8;
	for( i=3; i>=0; i-- )
	{
		output_set_digit_value(i+50, led_map[data%10]);
		data = data/10;
	}

	data = m_led_score>>8;
	for( i=3; i>=0; i-- )
	{
//		drawgfx_transpen( bitmap, led_font,
//			data%10,0, /* number, color */
//			0,1, /* no flip */
//			0,SCREEN_HEIGHT-6-i*6,
//			NULL, TRANSPARENCY_NONE,0 );

		output_set_digit_value(i, led_map[data%10]);

		data = data/10;
	}

	data = m_led_plays;
	for( i=2; i>=0; i-- )
	{
		output_set_digit_value(i+60, led_map[data%10]);
		data = data/10;
	}

	data = m_led_rank;
	for( i=2; i>=0; i-- )
	{
		if (data == 0xffff)
		{
			output_set_digit_value(i+70, 0);		/* make it blank */
		}
		else
		{
			output_set_digit_value(i+70, led_map[data%10]);
			data = data/10;
		}
	}

	data = m_led_speed;
	for( i=2; i>=0; i-- )
	{
//		drawgfx_transpen( bitmap, led_font,
//			data%10,0, /* number, color */
//			0,1, /* no flip */
//			9,SCREEN_HEIGHT-6-i*6,
//			NULL, TRANSPARENCY_NONE,0 );
//
		output_set_digit_value(i+80, led_map[data%10]);
		data = data/10;
	}

	data = m_led_gear;
	for( i=0; i>=0; i-- )
	{
		output_set_digit_value(i+90, led_map[10+data%10]);
		data = data/10;
	}

	data = m_led_lives;
	for( i=0; i>=0; i-- )
	{
		output_set_digit_value(i+100, led_map[data%10]);
		data = data/10;
	}

	data = m_led_time>>8;
	for( i=1; i>=0; i-- )
	{
//		drawgfx_opaque( bitmap, NULL, led_font,
//			data%10,0, /* number, color */
//			0,1, /* no flip */
//			18,SCREEN_HEIGHT-6-i*6 );

		output_set_digit_value(i+4, led_map[data%10]);

		data = data/10;
	}
}

void monaco_state::draw_signal( bitmap_ind16 &bitmap )
{
	if( m_bSignalVisible )
	{
//		drawgfx_opaque(
//			bitmap, NULL, machine().gfx[GFX_SIGNAL],
//			0,0, /* number, color */
//			0,0, /* no flip */
//			32,(SCREEN_HEIGHT - 32)/2 );
	}
}

UINT32 monaco_state::screen_update_monaco(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
{
	const rectangle &visarea = screen.visible_area();
	draw_background( bitmap, visarea );
	draw_pool( bitmap, visarea );
	draw_computer( bitmap, visarea );
	draw_light( bitmap );
	draw_wall( bitmap, visarea );
	draw_text( bitmap, visarea );
	draw_player( bitmap, visarea );
	draw_signal( bitmap );
	draw_leds( bitmap );
	return 0;
}

VIDEO_START_MEMBER( monaco_state, monaco )
{
	int i;

	palette_set_color_rgb( machine(), 0, 0x00,0x00,0x00 ); /* black (tire) */
	palette_set_color_rgb( machine(), 1, 0xff,0xff,0xff ); /* white (trim) */
	/* computer car */
	for( i=0; i<NUM_COMPUTER_CAR_TYPES; i++ )
	{
		const unsigned char clut[3*NUM_COMPUTER_CAR_TYPES] =
		{
			0x00,0xff,0x00, /* green car */
			0xff,0xff,0x00, /* yellow car */
			0x00,0xff,0xff, /* cyan car */
			0xff,0x00,0xff, /* purple car */
			0x00,0x00,0xff  /* blue car */
		};

		palette_set_color_rgb( machine(), 16*i+0x8, 0x00,0x00,0x00 ); /* black (tire) */
		palette_set_color_rgb( machine(), 16*i+0xa, 0xff,0xff,0xff ); /* white (trim) */
		palette_set_color_rgb( machine(), 16*i+0xc, clut[i*3+0],clut[i*3+1],clut[i*3+2] );
	}
	/* rescue car */
	palette_set_color_rgb( machine(), 0x50+0x8, 0x00,0x00,0x00 ); // black
	palette_set_color_rgb( machine(), 0x50+0x9, 0xff,0xff,0x00 ); // yellow
	palette_set_color_rgb( machine(), 0x50+0xa, 0xff,0xff,0xff ); // white
	palette_set_color_rgb( machine(), 0x50+0xc, 0xff,0x00,0x00 ); // red (light)
	/* house */
	palette_set_color_rgb( machine(), 0x60+0x0, 0x00,0x00,0x00 ); // ground
	palette_set_color_rgb( machine(), 0x60+0x9, 0xff,0x00,0x00 ); // right roof
	palette_set_color_rgb( machine(), 0x60+0xa, 0xff,0x00,231 ); // left roof
	palette_set_color_rgb( machine(), 0x60+0xb, 0x00,198,255 ); // front
	palette_set_color_rgb( machine(), 0x60+0xc, 0xff,0xff,0xff ); // trim
	/* water */
	palette_set_color_rgb( machine(), 0x70, 0x00,0x00,0xff );//l.blue
	palette_set_color_rgb( machine(), 0x71, 0xff,0x00,0x00 );//red
	palette_set_color_rgb( machine(), 0x72, 0xff,0xff,0x00 );//yellow
	palette_set_color_rgb( machine(), 0x73, 0x00,0x00,0x00 );//black
	palette_set_color_rgb( machine(), 0x74, 0x00,0x00,0x00 );//N/A
	palette_set_color_rgb( machine(), 0x75, 0xff,0xff,0xff );//white
	palette_set_color_rgb( machine(), 0x76, 0x9f,0x9f,0x9f );//grey (road)
	palette_set_color_rgb( machine(), 0x77, 0x00,0x00,0x9f );//d.blue
	/* player car */
	palette_set_color_rgb( machine(), 0x80, 0x00,0x00,0x00 );
	palette_set_color_rgb( machine(), 0x81, 0xff,0x00,0x00 ); // red (car body)
	palette_set_color_rgb( machine(), 0x82, 0xff,0xff,0xff ); // white (trim)
	palette_set_color_rgb( machine(), 0x83, 0x00,0x00,0x00 ); // black (tire)
	/* tree */
	palette_set_color_rgb( machine(), 0x84, 0xff,0xff,0x00 ); // yellow
	palette_set_color_rgb( machine(), 0x85, 0x00,0x00,0x00 ); // dark green
	palette_set_color_rgb( machine(), 0x86, 0x00,165,0x00 ); // light green
	palette_set_color_rgb( machine(), 0x87, 0x00,0x00,0x00 ); // black?
	/* shrub */
	palette_set_color_rgb( machine(), 0x88, 0x00,0x00,0x00 );
	palette_set_color_rgb( machine(), 0x89, 0x00,0xff,0x00 );
	palette_set_color_rgb( machine(), 0x8a, 0x00,0x00,0xff );
	palette_set_color_rgb( machine(), 0x8b, 0xff,0xff,0xff );
	/* grass */
	palette_set_color_rgb( machine(), 0x8c, 0x00,0x00,0x00 );
	palette_set_color_rgb( machine(), 0x8d, 0x00,0x9f,0x00 ); // dark green
	palette_set_color_rgb( machine(), 0x8e, 0x00,0x00,0x00 );
	palette_set_color_rgb( machine(), 0x8f, 0x00,0x00,0x9f ); // dark blue
	palette_set_color_rgb( machine(), 0x90, 0x00,0x00,0x00 ); // black
	palette_set_color_rgb( machine(), 0x91, 0x00,0xff,0xff ); // cyan
	palette_set_color_rgb( machine(), 0x92, 0x00,0x00,0x00 ); // grey
	palette_set_color_rgb( machine(), 0x93, 0xff,0x00,0x00 ); // red
	palette_set_color_rgb( machine(), 0x94, 0x00,0x00,0x00 ); // black
	palette_set_color_rgb( machine(), 0x95, 255,215,0 ); // yellow trim
	palette_set_color_rgb( machine(), 0x96, 132,132,132 ); // grey (road)
// 0,198,255: wet road
// 255,215,0: yellow trim
}
